@@ -15,12 +15,12 @@ Net::OAuth::Yahoo - Provides simple interface to access Yahoo! APIs
 
 =head1 VERSION
 
-Version 0.06
+Version 1.0.0
 
 =cut
 
-our $VERSION = '0.06';
-our $ERRMSG = undef;
+our $VERSION = '1.0.0';
+our $ERRMSG  = undef;
 $Net::OAuth::PROTOCOL_VERSION = Net::OAuth::PROTOCOL_VERSION_1_0A;
 
 =head1 SYNOPSIS
@@ -103,12 +103,12 @@ $Net::OAuth::PROTOCOL_VERSION = Net::OAuth::PROTOCOL_VERSION_1_0A;
 sub new {
     my ( $class, $args ) = @_;
     my $self = bless {}, $class;
-    
-    $self->_validate_params( $args );
-    $self->{ params } = $args;
-    $self->{ request_token_url } = "https://api.login.yahoo.com/oauth/v2/get_request_token";
-    $self->{ token_url } = "https://api.login.yahoo.com/oauth/v2/get_token";
-    $self->{ oauth } = undef;
+
+    $self->_validate_params($args);
+    $self->{params}            = $args;
+    $self->{request_token_url} = "https://api.login.yahoo.com/oauth/v2/get_request_token";
+    $self->{token_url}         = "https://api.login.yahoo.com/oauth/v2/get_token";
+    $self->{oauth}             = undef;
 
     return $self;
 }
@@ -123,17 +123,17 @@ sub new {
 
 sub get_request_token {
     my $self = shift;
-    
-    $self->{ oauth } = undef; # clears anything that may have existed
-    $self->{ oauth }->{ consumer_key } = $self->{ params }->{ consumer_key };
-    $self->{ oauth }->{ nonce } = $self->{ params }->{ nonce };
-    $self->{ oauth }->{ signature_method } = $self->{ params }->{ signature_method };
-    $self->{ oauth }->{ consumer_secret } = $self->{ params }->{ consumer_secret };
-    $self->{ oauth }->{ callback } = $self->{ params }->{ callback };
-    my $url = $self->{ request_token_url };
-    $self->{ request_token } = $self->_make_oauth_request( "request token", $url );
 
-    return $self->{ request_token };
+    $self->{oauth}                     = undef;                                 # clears anything that may have existed
+    $self->{oauth}->{consumer_key}     = $self->{params}->{consumer_key};
+    $self->{oauth}->{nonce}            = $self->{params}->{nonce};
+    $self->{oauth}->{signature_method} = $self->{params}->{signature_method};
+    $self->{oauth}->{consumer_secret}  = $self->{params}->{consumer_secret};
+    $self->{oauth}->{callback}         = $self->{params}->{callback};
+    my $url = $self->{request_token_url};
+    $self->{request_token} = $self->_make_oauth_request( "request token", $url );
+
+    return $self->{request_token};
 }
 
 =head2 get_token
@@ -145,24 +145,24 @@ sub get_request_token {
 
 sub get_token {
     my ( $self, $oauth_verifier ) = @_;
-    
+
     unless ( defined $oauth_verifier ) {
         $ERRMSG = "get_token() invoked without oauth_verifier";
         return undef;
     }
-    
-    $self->{ oauth } = undef;
-    $self->{ oauth }->{ consumer_key } = $self->{ params }->{ consumer_key };
-    $self->{ oauth }->{ signature_method } = $self->{ params }->{ signature_method };
-    $self->{ oauth }->{ nonce } = $self->{ params }->{ nonce };
-    $self->{ oauth }->{ consumer_secret } = $self->{ params }->{ consumer_secret };
-    $self->{ oauth }->{ verifier } = $oauth_verifier;
-    $self->{ oauth }->{ token } = $self->{ request_token }->{ oauth_token };
-    $self->{ oauth }->{ token_secret } = $self->{ request_token }->{ oauth_token_secret };
-    my $url = $self->{ token_url };
-    $self->{ token } = $self->_make_oauth_request( "access token", $url );
-    
-    return $self->{ token };
+
+    $self->{oauth}                     = undef;
+    $self->{oauth}->{consumer_key}     = $self->{params}->{consumer_key};
+    $self->{oauth}->{signature_method} = $self->{params}->{signature_method};
+    $self->{oauth}->{nonce}            = $self->{params}->{nonce};
+    $self->{oauth}->{consumer_secret}  = $self->{params}->{consumer_secret};
+    $self->{oauth}->{verifier}         = $oauth_verifier;
+    $self->{oauth}->{token}            = $self->{request_token}->{oauth_token};
+    $self->{oauth}->{token_secret}     = $self->{request_token}->{oauth_token_secret};
+    my $url = $self->{token_url};
+    $self->{token} = $self->_make_oauth_request( "access token", $url );
+
+    return $self->{token};
 }
 
 =head2 access_api
@@ -180,14 +180,14 @@ sub access_api {
         $ERRMSG = "access_api() did not receive a token or URL";
         return undef;
     }
-    
-    $self->{ oauth } = undef;
-    $self->{ oauth }->{ consumer_key } = $self->{ params }->{ consumer_key };
-    $self->{ oauth }->{ nonce } = $self->{ params }->{ nonce };
-    $self->{ oauth }->{ signature_method } = $self->{ params }->{ signature_method };
-    $self->{ oauth }->{ token } = uri_unescape( $token->{ oauth_token } );
-    $self->{ oauth }->{ token_secret } = $token->{ oauth_token_secret };
-    $self->{ oauth }->{ consumer_secret } = $self->{ params }->{ consumer_secret };
+
+    $self->{oauth}                     = undef;
+    $self->{oauth}->{consumer_key}     = $self->{params}->{consumer_key};
+    $self->{oauth}->{nonce}            = $self->{params}->{nonce};
+    $self->{oauth}->{signature_method} = $self->{params}->{signature_method};
+    $self->{oauth}->{token}            = uri_unescape( $token->{oauth_token} );
+    $self->{oauth}->{token_secret}     = $token->{oauth_token_secret};
+    $self->{oauth}->{consumer_secret}  = $self->{params}->{consumer_secret};
 
     return $self->_make_oauth_request( "protected resource", $url );
 }
@@ -200,34 +200,34 @@ sub access_api {
 
 sub _make_oauth_request {
     my ( $self, $req_type, $url ) = @_;
-    
+
     unless ( defined $url ) {
         $ERRMSG = "_make_oauth_request() could not come up with a URL to make an API request";
         return undef;
     }
 
     my $ua = LWP::UserAgent->new;
-    
+
     my $request = Net::OAuth->request($req_type)->new(
-        %{ $self->{ oauth } },
+        %{ $self->{oauth} },
         request_method => "GET",
-        request_url => $url,
-        timestamp => time,
+        request_url    => $url,
+        timestamp      => time,
     );
 
     $request->sign;
     my $req = HTTP::Request->new( "GET" => $request->to_url );
-    my $res = $ua->request( $req );
-    
+    my $res = $ua->request($req);
+
     #print Dumper($res);
 
-    if ($res->is_success) {
+    if ( $res->is_success ) {
         return $res->content unless ( $req_type eq "request token" || $req_type eq "access token" );
-        
+
         my @args_array = split( /&/, $res->content );
         my $args_ref;
 
-        for ( @args_array ) {
+        for (@args_array) {
             my ( $k, $v ) = split( /=/, $_ );
             $args_ref->{$k} = $v;
         }
@@ -248,12 +248,12 @@ sub _validate_params {
     my ( $self, $args ) = @_;
     my @list = ( "consumer_key", "consumer_secret", "signature_method", "nonce", "callback" );
     my @keys = keys %{$args};
-    
-    for my $required_key ( @list ) {
+
+    for my $required_key (@list) {
         unless ( grep( /^$required_key$/, @keys ) ) {
             $ERRMSG = "_validate_params() failed";
             return undef;
-        } 
+        }
     }
     return 1;
 }
@@ -268,13 +268,13 @@ sub _validate_params {
 
 sub request_auth {
     my ( $self, $token ) = @_;
-    
-    if ( defined $token->{ xoauth_request_auth_url } ) {
-        return uri_unescape( $token->{ xoauth_request_auth_url } );
+
+    if ( defined $token->{xoauth_request_auth_url} ) {
+        return uri_unescape( $token->{xoauth_request_auth_url} );
     }
     else {
         $ERRMSG = "request_auth() did not receive a valid request token";
-        return  undef;
+        return undef;
     }
 }
 
@@ -293,34 +293,32 @@ sub request_auth {
 
 sub sim_present_auth {
     my ( $self, $url, $yid ) = @_;
-    
-    unless ( defined $url && defined $yid->{ login } && defined $yid->{ passwd } ) {
+
+    unless ( defined $url && defined $yid->{login} && defined $yid->{passwd} ) {
         $ERRMSG = "sim_present_auth() did not receive correct set of params";
         return undef;
     }
 
     my $mech = new WWW::Mechanize( autocheck => 1 );
-    $mech->get( $url );
+    $mech->get($url);
 
-    $mech->submit_form (
-        form_name => "login_form",
-        fields => {
-            login => $yid->{ login },
-            passwd => $yid->{ passwd },
+    $mech->submit_form(
+        form_number => 0,
+        fields    => {
+            login  => $yid->{login},
+            passwd => $yid->{passwd},
         },
     );
 
-    $mech->submit_form (
-        button => "agree"
-    );
-    
+    $mech->submit_form( button => "agree" );
+
     my ($code) = $mech->content =~ m|<span id="shortCode">(\w+)</span>|;
-    
+
     unless ( defined $code ) {
         $ERRMSG = "sim_present_auth() could not get oauth_verifier";
         return undef;
     }
-    
+
     return $code;
 }
 
@@ -333,12 +331,12 @@ sub sim_present_auth {
 
 sub save_token {
     my ( $self, $file ) = @_;
-    
-    unless ( defined $file && defined $self->{ token } ) {
+
+    unless ( defined $file && defined $self->{token} ) {
         $ERRMSG = "save_token() did not receive filename or, object did not have a token";
         return undef;
     }
-    YAML::Syck::DumpFile( $file, $self->{ token } );
+    YAML::Syck::DumpFile( $file, $self->{token} );
 }
 
 =head2 load_token
@@ -350,20 +348,20 @@ sub save_token {
 
 sub load_token {
     my ( $self, $file ) = @_;
-    
+
     unless ( defined $file && -f $file ) {
         $ERRMSG = "load_token() could not find the file specified";
         return undef;
     }
-    
-    my $ref = YAML::Syck::LoadFile( $file );
-    
-    unless ( defined $ref->{ oauth_token } && defined $ref->{ oauth_token_secret } ) {
+
+    my $ref = YAML::Syck::LoadFile($file);
+
+    unless ( defined $ref->{oauth_token} && defined $ref->{oauth_token_secret} ) {
         $ERRMSG = "load_token() token does not seem valid";
-        return  undef;
+        return undef;
     }
 
-    $self->{ token } = $ref;
+    $self->{token} = $ref;
     return $ref;
 }
 
@@ -377,12 +375,12 @@ sub load_token {
 
 sub test_token {
     my ( $self, $token, $url ) = @_;
-    
+
     unless ( defined $token && defined $url ) {
         $ERRMSG = "test_token() did not receive the right params";
         return undef;
     }
-    
+
     my $output = $self->access_api( $token, $url );
     ( defined $output ) ? return 1 : return 0;
 }
@@ -396,7 +394,7 @@ sub test_token {
 
 sub get {
     my ( $self, $item ) = @_;
-    ( defined $self->{ $item } ) ? return $self->{ $item } : undef; 
+    ( defined $self->{$item} ) ? return $self->{$item} : undef;
 }
 
 =head1 AUTHOR
@@ -458,4 +456,4 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
-1; # End of Net::OAuth::Yahoo
+1;    # End of Net::OAuth::Yahoo
